pub struct AuthState {
pub secret: Vec<u8>,
pub vault_unlocked: Arc<Mutex<bool>>,
}Fields
secret: Vec<u8>vault_unlocked: Arc<Mutex<bool>>Implementations
Sourceimpl AuthState
impl AuthState
pub fn new() -> Self
pub fn set_vault_unlocked(&self, unlocked: bool)
Sourcepub fn is_vault_unlocked(&self) -> bool
pub fn is_vault_unlocked(&self) -> bool
Errors
This function does not return errors, but may return false if:
- The mutex lock is poisoned or cannot be acquired
Sourcepub fn generate_token(&self, scopes: Vec<String>) -> ApiResult<String>
pub fn generate_token(&self, scopes: Vec<String>) -> ApiResult<String>
Errors
This function returns an error if:
- Token expiration timestamp conversion fails
- Token issue timestamp conversion fails
- Token generation process fails
Sourcepub fn verify_token(&self, token: &str) -> ApiResult<TokenClaims>
pub fn verify_token(&self, token: &str) -> ApiResult<TokenClaims>
Errors
This function returns an error if:
- The token is invalid or expired
- The token signature is invalid
- The token format is incorrect